Examples
========

This section contains practical examples of using the IDL package.

.. toctree::
   :maxdepth: 10
   :hidden:

   examples/idl-mnist
   examples/sim-mnist

.. raw:: html

   <meta http-equiv="refresh" content="0; url=examples/idl-mnist.html">

   <script>
      window.location.href = "examples/idl-mnist.html";
   </script>

   <p>If you are not redirected automatically, follow this <a href="examples/idl-mnist.html">link to the MNIST example</a>.</p>